<!--
SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
SPDX-License-Identifier: BSD-2-Clause
-->

# run-isolated - API reference

## Top-level reexported definitions

::: run_isolated

## Run commands within a Docker container

::: run_isolated.rdocker.Config

::: run_isolated.rdocker.ContainerVolume

::: run_isolated.rdocker.Container

## Docker container errors

::: run_isolated.rdocker.DockerError

::: run_isolated.rdocker.CommandError

::: run_isolated.rdocker.CommandRunError

::: run_isolated.rdocker.CommandFailError

::: run_isolated.rdocker.CommandDecodeOutputError

## Helper utility functions

::: run_isolated.util.DEFAULT_LOGGER_NAME

::: run_isolated.util.build_logger
